@@ -65,6 +65,7 @@ public class InstanceManager extends AbstractDaemon {
     private final ConcurrentHashMap<String, Instance> instanceMap;
     // instance profile queue.
     private final BlockingQueue<InstanceAction> actionQueue;
+    private final BlockingQueue<InstanceAction> addActionQueue;
     // task thread pool;
     private static final ThreadPoolExecutor EXECUTOR_SERVICE = new ThreadPoolExecutor(
             0, Integer.MAX_VALUE,
@@ -79,6 +80,7 @@ public class InstanceManager extends AbstractDaemon {
     private volatile boolean runAtLeastOneTime = false;
     private volatile boolean running = false;
     private final double reserveCoefficient = 0.8;
+    private long finishedInstanceCount = 0;
 
     private class InstancePrintStat {
 
@@ -124,6 +126,7 @@ public class InstanceManager extends AbstractDaemon {
         instanceMap = new ConcurrentHashMap<>();
         this.instanceLimit = instanceLimit;
         actionQueue = new LinkedBlockingQueue<>(ACTION_QUEUE_CAPACITY);
+        addActionQueue = new LinkedBlockingQueue<>(ACTION_QUEUE_CAPACITY);
     }
 
     public String getTaskId() {
@@ -146,6 +149,9 @@ public class InstanceManager extends AbstractDaemon {
         if (action == null) {
             return false;
         }
+        if (isFull()) {
+            return false;
+        }
         return actionQueue.offer(action);
     }
 
@@ -162,7 +168,8 @@ public class InstanceManager extends AbstractDaemon {
                 try {
                     AgentUtils.silenceSleepInMs(CORE_THREAD_SLEEP_TIME_MS);
                     printInstanceState();
-                    dealWithActionQueue(actionQueue);
+                    dealWithActionQueue();
+                    dealWithAddActionQueue();
                     keepPaceWithStore();
                     String inlongGroupId = taskFromStore.getInlongGroupId();
                     String inlongStreamId = taskFromStore.getInlongStreamId();
@@ -250,16 +257,18 @@ public class InstanceManager extends AbstractDaemon {
         });
     }
 
-    private void dealWithActionQueue(BlockingQueue<InstanceAction> queue) {
+    private void dealWithActionQueue() {
         while (isRunnable()) {
             try {
-                InstanceAction action = queue.poll();
+                InstanceAction action = actionQueue.poll();
                 if (action == null) {
                     break;
                 }
                 switch (action.getActionType()) {
                     case ADD:
-                        addInstance(action.getProfile());
+                        if (!addActionQueue.offer(action)) {
+                            LOGGER.error("it should never happen: addQueue is full");
+                        }
                         break;
                     case FINISH:
                         finishInstance(action.getProfile());
@@ -278,6 +287,20 @@ public class InstanceManager extends AbstractDaemon {
         }
     }
 
+    private void dealWithAddActionQueue() {
+        while (isRunnable()) {
+            if (instanceMap.size() > instanceLimit) {
+                LOGGER.error("instanceMap size {} over limit {}", instanceMap.size(), instanceLimit);
+                return;
+            }
+            InstanceAction action = addActionQueue.poll();
+            if (action == null) {
+                break;
+            }
+            addInstance(action.getProfile());
+        }
+    }
+
     @Override
     public void start() {
         restoreFromStore();
@@ -316,10 +339,6 @@ public class InstanceManager extends AbstractDaemon {
     }
 
     private void addInstance(InstanceProfile profile) {
-        if (instanceMap.size() >= instanceLimit) {
-            LOGGER.error("instanceMap size {} over limit {}", instanceMap.size(), instanceLimit);
-            return;
-        }
         LOGGER.info("add instance taskId {} instanceId {}", taskId, profile.getInstanceId());
         if (!shouldAddAgain(profile.getInstanceId(), profile.getFileUpdateTime())) {
             LOGGER.info("addInstance shouldAddAgain returns false skip taskId {} instanceId {}", taskId,
@@ -337,6 +356,7 @@ public class InstanceManager extends AbstractDaemon {
         deleteFromMemory(profile.getInstanceId());
         LOGGER.info("finished instance state {} taskId {} instanceId {}", profile.getState(),
                 profile.getTaskId(), profile.getInstanceId());
+        finishedInstanceCount++;
     }
 
     private void deleteInstance(String instanceId) {
@@ -371,6 +391,15 @@ public class InstanceManager extends AbstractDaemon {
                 instance.getProfile().getSinkDataTime(), 1, 1, auditVersion);
     }
 
+    private void notifyDestroyInstance(String instanceId) {
+        Instance instance = instanceMap.get(instanceId);
+        if (instance == null) {
+            LOGGER.error("try to notify destroy instance but not found: taskId {} instanceId {}", taskId, instanceId);
+            return;
+        }
+        instance.notifyDestroy();
+    }
+
     private void addToStore(InstanceProfile profile, boolean addNew) {
         LOGGER.info("add instance to instance store state {} instanceId {}", profile.getState(),
                 profile.getInstanceId());
@@ -424,11 +453,14 @@ public class InstanceManager extends AbstractDaemon {
                         instanceProfile.getSinkDataTime(), 1, 1, auditVersion);
             }
         } catch (Throwable t) {
-            LOGGER.error("add instance error {}", t.getMessage());
+            LOGGER.error("add instance error.", t);
         }
     }
 
     private void stopAllInstances() {
+        instanceMap.values().forEach((instance) -> {
+            notifyDestroyInstance(instance.getInstanceId());
+        });
         instanceMap.values().forEach((instance) -> {
             deleteFromMemory(instance.getInstanceId());
         });
@@ -455,26 +487,17 @@ public class InstanceManager extends AbstractDaemon {
     }
 
     public boolean isFull() {
-        return (instanceMap.size() + actionQueue.size()) >= instanceLimit * reserveCoefficient;
+        return (actionQueue.size() + addActionQueue.size()) >= ACTION_QUEUE_CAPACITY * reserveCoefficient;
     }
 
-    public boolean allInstanceFinished() {
-        if (!runAtLeastOneTime) {
-            return false;
-        }
-        if (!instanceMap.isEmpty()) {
-            return false;
-        }
-        if (!actionQueue.isEmpty()) {
-            return false;
-        }
+    public long getFinishedInstanceCount() {
+        int count = 0;
         List<InstanceProfile> instances = instanceStore.getInstances(taskId);
         for (int i = 0; i < instances.size(); i++) {
-            InstanceProfile profile = instances.get(i);
-            if (profile.getState() != InstanceStateEnum.FINISHED) {
-                return false;
+            if (instances.get(i).getState() == InstanceStateEnum.FINISHED) {
+                count++;
             }
         }
-        return true;
+        return count;
     }
 }
\ No newline at end of file
