@@ -28,6 +28,7 @@ import org.apache.inlong.agent.utils.AgentUtils;
 import org.apache.inlong.agent.utils.HttpManager;
 import org.apache.inlong.agent.utils.ThreadUtils;
 import org.apache.inlong.common.enums.PullJobTypeEnum;
+import org.apache.inlong.common.enums.TaskTypeEnum;
 import org.apache.inlong.common.pojo.agent.AgentConfigInfo;
 import org.apache.inlong.common.pojo.agent.AgentConfigRequest;
 import org.apache.inlong.common.pojo.agent.AgentResponseCode;
@@ -42,10 +43,7 @@ import com.google.gson.JsonObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.text.ParseException;
-import java.text.SimpleDateFormat;
 import java.util.ArrayList;
-import java.util.Date;
 import java.util.List;
 
 import static org.apache.inlong.agent.constant.AgentConstants.AGENT_CLUSTER_NAME;
@@ -84,10 +82,6 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
     private String uuid;
     private String clusterTag;
     private String clusterName;
-    private String taskResultMd5;
-    private Integer taskResultVersion = -1;
-    private String agentConfigMd5;
-    private Integer agentConfigVersion = -1;
 
     public ManagerFetcher(AgentManager agentManager) {
         this.agentManager = agentManager;
@@ -167,7 +161,7 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
 
     public TaskRequest getTaskRequest() {
         TaskRequest request = new TaskRequest();
-        request.setMd5(taskResultMd5);
+        request.setMd5(agentManager.getTaskManager().getTaskResultMd5());
         request.setAgentIp(localIp);
         request.setUuid(uuid);
         request.setClusterName(clusterName);
@@ -178,7 +172,9 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
 
     public AgentConfigRequest getAgentConfigInfoRequest() {
         AgentConfigRequest request = new AgentConfigRequest();
-        request.setMd5(agentConfigMd5);
+        if (AgentManager.getAgentConfigInfo() != null) {
+            request.setMd5(AgentManager.getAgentConfigInfo().getMd5());
+        }
         request.setClusterTag(clusterTag);
         request.setClusterName(clusterName);
         request.setIp(localIp);
@@ -197,22 +193,22 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
                 try {
                     TaskResult taskResult = getStaticConfig();
                     if (taskResult != null && taskResult.getCode().equals(AgentResponseCode.SUCCESS)
-                            && taskResultVersion < taskResult.getVersion()) {
+                            && agentManager.getTaskManager().getTaskResultVersion() < taskResult.getVersion()) {
                         List<TaskProfile> taskProfiles = new ArrayList<>();
                         taskResult.getDataConfigs().forEach((config) -> {
                             TaskProfile profile = TaskProfile.convertToTaskProfile(config);
                             taskProfiles.add(profile);
                         });
                         agentManager.getTaskManager().submitTaskProfiles(taskProfiles);
-                        taskResultMd5 = taskResult.getMd5();
-                        taskResultVersion = taskResult.getVersion();
+                        agentManager.getTaskManager().setTaskResultMd5(taskResult.getMd5());
+                        agentManager.getTaskManager().setTaskResultVersion(taskResult.getVersion());
                     }
                     AgentConfigInfo config = getAgentConfigInfo();
-                    if (config != null && config.getCode().equals(AgentResponseCode.SUCCESS)
-                            && agentConfigVersion < config.getVersion()) {
-                        agentManager.subNewAgentConfigInfo(config);
-                        agentConfigMd5 = config.getMd5();
-                        agentConfigVersion = config.getVersion();
+                    if (config != null && config.getCode().equals(AgentResponseCode.SUCCESS)) {
+                        if (AgentManager.getAgentConfigInfo() == null
+                                || AgentManager.getAgentConfigInfo().getVersion() < config.getVersion()) {
+                            agentManager.subNewAgentConfigInfo(config);
+                        }
                     }
                 } catch (Throwable ex) {
                     LOGGER.warn("exception caught", ex);
@@ -227,32 +223,22 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
 
     private TaskResult getTestConfig(String testDir, int normalTaskId, int retryTaskId, int state) {
         List<DataConfig> configs = new ArrayList<>();
-        String startStr = "2023-07-10 00:00:00";
-        String endStr = "2023-07-22 00:00:00";
-        Long start = 0L;
-        Long end = 0L;
         String normalPattern = testDir + "YYYY/YYYYMMDDhhmm_2.log_[0-9]+";
         String retryPattern = testDir + "YYYY/YYYYMMDD_1.log_[0-9]+";
-        try {
-            Date parse = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(startStr);
-            start = parse.getTime();
-            parse = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").parse(endStr);
-            end = parse.getTime();
-        } catch (ParseException e) {
-            e.printStackTrace();
-        }
-        configs.add(getTestDataConfig(normalTaskId, normalPattern, false, start, end, CycleUnitType.MINUTE, state));
-        configs.add(getTestDataConfig(retryTaskId, retryPattern, true, start, end, CycleUnitType.DAY, state));
+        configs.add(getTestDataConfig(normalTaskId, normalPattern, false, "202307100000", "202307220000",
+                CycleUnitType.MINUTE, state));
+        configs.add(
+                getTestDataConfig(retryTaskId, retryPattern, true, "20230710", "20230722", CycleUnitType.DAY, state));
         return TaskResult.builder().dataConfigs(configs).build();
     }
 
-    private DataConfig getTestDataConfig(int taskId, String pattern, boolean retry, Long startTime, Long endTime,
+    private DataConfig getTestDataConfig(int taskId, String pattern, boolean retry, String startTime, String endTime,
             String cycleUnit, int state) {
         DataConfig dataConfig = new DataConfig();
         dataConfig.setInlongGroupId("devcloud_group_id");
         dataConfig.setInlongStreamId("devcloud_stream_id");
         dataConfig.setDataReportType(0);
-        dataConfig.setTaskType(3);
+        dataConfig.setTaskType(TaskTypeEnum.FILE.getType());
         dataConfig.setTaskId(taskId);
         dataConfig.setState(state);
         dataConfig.setTimeZone("GMT+8:00");
@@ -262,8 +248,8 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
         fileTaskConfig.setMaxFileCount(100);
         fileTaskConfig.setCycleUnit(cycleUnit);
         fileTaskConfig.setRetry(retry);
-        fileTaskConfig.setStartTime(startTime);
-        fileTaskConfig.setEndTime(endTime);
+        fileTaskConfig.setDataTimeFrom(startTime);
+        fileTaskConfig.setDataTimeTo(endTime);
         fileTaskConfig.setDataContentStyle("CSV");
         fileTaskConfig.setDataSeparator("|");
         dataConfig.setExtParams(GSON.toJson(fileTaskConfig));
