@@ -28,6 +28,7 @@ import org.apache.inlong.agent.plugin.file.Task;
 import org.apache.inlong.agent.state.State;
 import org.apache.inlong.agent.store.Store;
 import org.apache.inlong.agent.utils.AgentUtils;
+import org.apache.inlong.agent.utils.ThreadUtils;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -51,6 +52,7 @@ public abstract class AbstractTask extends Task {
     protected boolean initOK = false;
     protected long lastPrintTime = 0;
     protected long auditVersion;
+    protected long instanceCount = 0;
 
     @Override
     public void init(Object srcManager, TaskProfile taskProfile, Store basicStore) throws IOException {
@@ -111,6 +113,7 @@ public abstract class AbstractTask extends Task {
             doRun();
         } catch (Throwable e) {
             LOGGER.error("do run error: ", e);
+            ThreadUtils.threadThrowableHandler(Thread.currentThread(), e);
         }
         running = false;
     }
@@ -150,7 +153,7 @@ public abstract class AbstractTask extends Task {
     }
 
     protected boolean allInstanceFinished() {
-        return instanceManager.allInstanceFinished();
+        return instanceCount == instanceManager.getFinishedInstanceCount();
     }
 
     protected boolean shouldAddAgain(String fileName, long lastModifyTime) {
