@@ -96,6 +96,14 @@ export class SourceDefaultInfo implements DataWithBackend, RenderRow, RenderList
   @I18n('meta.Sources.Type')
   sourceType: string;
 
+  @FieldDecorator({
+    type: 'select',
+    hidden: true,
+  })
+  @IngestionField()
+  @I18n('meta.Sources.File.ClusterName')
+  readonly clusterTag: string;
+
   @FieldDecorator({
     type: 'input',
     rules: [
@@ -118,6 +126,10 @@ export class SourceDefaultInfo implements DataWithBackend, RenderRow, RenderList
   @I18n('meta.Sources.Name')
   sourceName: string;
 
+  @ColumnDecorator()
+  @I18n('meta.Sources.ClusterName')
+  readonly inlongClusterName: string;
+
   @FieldDecorator({
     type: 'select',
     props: {
