@@ -17,11 +17,10 @@
 
 package org.apache.inlong.manager.service.core;
 
+import org.apache.inlong.audit.entity.AuditInformation;
+import org.apache.inlong.audit.entity.AuditProxy;
 import org.apache.inlong.common.enums.IndicatorType;
-import org.apache.inlong.manager.pojo.audit.AuditBaseResponse;
 import org.apache.inlong.manager.pojo.audit.AuditRequest;
-import org.apache.inlong.manager.pojo.audit.AuditSourceRequest;
-import org.apache.inlong.manager.pojo.audit.AuditSourceResponse;
 import org.apache.inlong.manager.pojo.audit.AuditVO;
 
 import java.util.List;
@@ -47,7 +46,7 @@ public interface AuditService {
      */
     List<AuditVO> listAll(AuditRequest request) throws Exception;
 
-    List<AuditBaseResponse> getAuditBases();
+    List<AuditInformation> getAuditBases(Boolean isMetric);
 
     /**
      * Get audit id by type and indicator type.
@@ -66,20 +65,10 @@ public interface AuditService {
     Boolean refreshBaseItemCache();
 
     /**
-     * Offline the old audit source through url, and insert and online a new audit source.
-     * If the new url already exists in the table, the insert operation will become an update operation.
+     * Get audit proxy url by component
      *
-     * @param operator current operator
-     * @param request audit source request
-     * @return audit source id after updating or saving
+     * @return audit proxy list
      */
-    Integer updateAuditSource(AuditSourceRequest request, String operator);
-
-    /**
-     * Get audit source that is online.
-     *
-     * @return audit source response.
-     */
-    AuditSourceResponse getAuditSource();
+    List<AuditProxy> getAuditProxy(String component) throws Exception;
 
 }
