@@ -85,6 +85,7 @@ import org.apache.inlong.manager.service.source.bounded.BoundedSourceType;
 import org.apache.inlong.manager.service.stream.InlongStreamService;
 import org.apache.inlong.manager.service.tenant.InlongTenantService;
 import org.apache.inlong.manager.service.user.InlongRoleService;
+import org.apache.inlong.manager.service.user.UserService;
 import org.apache.inlong.manager.service.workflow.WorkflowService;
 
 import com.fasterxml.jackson.core.type.TypeReference;
@@ -104,6 +105,7 @@ import org.springframework.transaction.annotation.Propagation;
 import org.springframework.transaction.annotation.Transactional;
 import org.springframework.validation.annotation.Validated;
 
+import java.sql.Timestamp;
 import java.time.LocalDateTime;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -165,6 +167,8 @@ public class InlongGroupServiceImpl implements InlongGroupService {
     private InlongRoleService inlongRoleService;
     @Autowired
     private TenantUserRoleEntityMapper tenantUserRoleEntityMapper;
+    @Autowired
+    private UserService userService;
 
     @Autowired
     ScheduleOperator scheduleOperator;
@@ -204,7 +208,7 @@ public class InlongGroupServiceImpl implements InlongGroupService {
         Preconditions.expectNotNull(request, "inlong group request cannot be empty");
 
         String groupId = request.getInlongGroupId();
-        InlongGroupEntity entity = groupMapper.selectByGroupId(groupId);
+        InlongGroupEntity entity = groupMapper.selectByGroupIdWithoutTenant(groupId);
         if (entity != null) {
             LOGGER.error("groupId={} has already exists", groupId);
             throw new BusinessException(ErrorCodeEnum.GROUP_DUPLICATE);
@@ -221,6 +225,7 @@ public class InlongGroupServiceImpl implements InlongGroupService {
 
         // save schedule info for offline group
         if (DATASYNC_OFFLINE_MODE.equals(request.getInlongGroupMode())) {
+            constrainStartAndEndTime(request);
             scheduleOperator.saveOpt(CommonBeanUtils.copyProperties(request, ScheduleInfoRequest::new), operator);
         }
 
@@ -228,6 +233,29 @@ public class InlongGroupServiceImpl implements InlongGroupService {
         return groupId;
     }
 
+    /**
+     * Add constraints to the start and end time of the offline synchronization group.
+     * 1. startTime must >= current time
+     * 2. endTime must >= startTime
+     * */
+    private void constrainStartAndEndTime(InlongGroupRequest request) {
+        Timestamp startTime = request.getStartTime();
+        Timestamp endTime = request.getEndTime();
+        Preconditions.expectTrue(startTime != null && endTime != null, "start time or end time cannot be empty");
+        long currentTime = System.currentTimeMillis();
+        if (startTime.getTime() < currentTime) {
+            Timestamp newStartTime = new Timestamp(currentTime);
+            request.setStartTime(newStartTime);
+            LOGGER.warn("start time is less than current time, re-set to current time for groupId={}, "
+                    + "startTime={}, newStartTime={}", request.getInlongGroupId(), startTime, newStartTime);
+        }
+        if (request.getStartTime().getTime() > endTime.getTime()) {
+            request.setEndTime(request.getStartTime());
+            LOGGER.warn("end time is less than start time, re-set end time to start time for groupId={}, "
+                    + "endTime={}, newEndTime={}", request.getInlongGroupId(), endTime, request.getEndTime());
+        }
+    }
+
     @Override
     @Transactional(rollbackFor = Throwable.class)
     public List<BatchResult> batchSave(List<InlongGroupRequest> groupRequestList, String operator) {
@@ -253,7 +281,7 @@ public class InlongGroupServiceImpl implements InlongGroupService {
     @Override
     public Boolean exist(String groupId) {
         Preconditions.expectNotNull(groupId, ErrorCodeEnum.GROUP_ID_IS_EMPTY.getMessage());
-        InlongGroupEntity entity = groupMapper.selectByGroupId(groupId);
+        InlongGroupEntity entity = groupMapper.selectByGroupIdWithoutTenant(groupId);
         LOGGER.debug("success to check inlong group {}, exist? {}", groupId, entity != null);
         return entity != null;
     }
@@ -284,24 +312,18 @@ public class InlongGroupServiceImpl implements InlongGroupService {
         groupInfo.setSortConf(sortConf);
         if (DATASYNC_OFFLINE_MODE.equals(entity.getInlongGroupMode())) {
             // get schedule info and set into group info
-            addScheduleInfo(entity, groupInfo);
+            fillInScheduleInfo(entity, groupInfo);
         }
         LOGGER.debug("success to get inlong group for groupId={}", groupId);
         return groupInfo;
     }
 
-    private void addScheduleInfo(InlongGroupEntity entity, InlongGroupInfo groupInfo) {
-        checkOfflineSyncScheduleExist(entity);
-        ScheduleInfo scheduleInfo = scheduleOperator.getScheduleInfo(entity.getInlongGroupId());
-        CommonBeanUtils.copyProperties(scheduleInfo, groupInfo);
-    }
-
-    private void checkOfflineSyncScheduleExist(InlongGroupEntity entity) {
-        // check schedule info for offline sync
-        if (!isScheduleInfoExist(entity)) {
-            String errorMsg = String.format("Schedule info not found for groupId=%s", entity.getInlongGroupId());
-            LOGGER.error(errorMsg);
-            throw new BusinessException(ErrorCodeEnum.SCHEDULE_NOT_FOUND, errorMsg);
+    private void fillInScheduleInfo(InlongGroupEntity entity, InlongGroupInfo groupInfo) {
+        if (isScheduleInfoExist(entity)) {
+            ScheduleInfo scheduleInfo = scheduleOperator.getScheduleInfo(entity.getInlongGroupId());
+            int groupVersion = groupInfo.getVersion();
+            CommonBeanUtils.copyProperties(scheduleInfo, groupInfo);
+            groupInfo.setVersion(groupVersion);
         }
     }
 
@@ -482,6 +504,8 @@ public class InlongGroupServiceImpl implements InlongGroupService {
             LOGGER.error("inlong group not found by groupId={}", groupId);
             throw new BusinessException(ErrorCodeEnum.GROUP_NOT_FOUND);
         }
+        userService.checkUser(entity.getInCharges(), operator,
+                "Current user does not have permission to update group info");
         chkUnmodifiableParams(entity, request);
         // check whether the current status can be modified
         doUpdateCheck(entity, request, operator);
@@ -498,8 +522,12 @@ public class InlongGroupServiceImpl implements InlongGroupService {
 
         // save schedule info for offline group
         if (DATASYNC_OFFLINE_MODE.equals(request.getInlongGroupMode())) {
-            scheduleOperator.updateAndRegister(CommonBeanUtils.copyProperties(request, ScheduleInfoRequest::new),
-                    operator);
+            constrainStartAndEndTime(request);
+            ScheduleInfoRequest scheduleRequest = CommonBeanUtils.copyProperties(request, ScheduleInfoRequest::new);
+            if (scheduleOperator.scheduleInfoExist(groupId)) {
+                scheduleRequest.setVersion(scheduleOperator.getScheduleInfo(groupId).getVersion());
+            }
+            scheduleOperator.updateAndRegister(scheduleRequest, operator);
         }
 
         LOGGER.info("success to update inlong group for groupId={} by user={}", groupId, operator);
