@@ -1,45 +1,45 @@
-/**
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 #include "send_group.h"
-#include "api_code.h"
-#include "proxy_manager.h"
+#include <sys/prctl.h>
 #include <algorithm>
 #include <random>
+#include "../core/api_code.h"
+#include "../manager/proxy_manager.h"
 
 namespace inlong {
-const int kDefaultQueueSize = 20;
+const uint32_t kDefaultQueueSize = 200;
 SendGroup::SendGroup(std::string send_group_key)
     : work_(asio::make_work_guard(io_context_)),
-      send_group_key_(send_group_key), send_idx_(0), dispatch_stat_(0),
-      load_threshold_(0), max_proxy_num_(0) {
-  max_send_queue_num_ = SdkConfig::getInstance()->send_buf_size_ /
-                        SdkConfig::getInstance()->pack_size_;
-  if (max_send_queue_num_ <= 0) {
+      send_group_key_(send_group_key),
+      send_idx_(0),
+      dispatch_stat_(0),
+      load_threshold_(0),
+      max_proxy_num_(0) {
+  max_send_queue_num_ = SdkConfig::getInstance()->send_buf_size_ / SdkConfig::getInstance()->pack_size_;
+  if (max_send_queue_num_ <= kDefaultQueueSize) {
     max_send_queue_num_ = kDefaultQueueSize;
   }
-  LOG_INFO("SendGroup:" << send_group_key_
-                         << ",max send queue num:" << max_send_queue_num_);
+  max_send_queue_num_ = std::max(max_send_queue_num_, kDefaultQueueSize);
+  LOG_INFO("SendGroup:" << send_group_key_ << ",max send queue num:" << max_send_queue_num_);
   dispatch_interval_ = SdkConfig::getInstance()->dispatch_interval_send_;
   load_balance_interval_ = SdkConfig::getInstance()->load_balance_interval_;
-  heart_beat_interval_ =
-      SdkConfig::getInstance()->heart_beat_interval_ / dispatch_interval_;
+  heart_beat_interval_ = SdkConfig::getInstance()->heart_beat_interval_ / dispatch_interval_;
   need_balance_ = SdkConfig::getInstance()->enable_balance_;
 
   work_clients_old_ = nullptr;
@@ -48,23 +48,19 @@ SendGroup::SendGroup(std::string send_group_key)
 
   send_timer_ = std::make_shared<asio::steady_timer>(io_context_);
   send_timer_->expires_after(std::chrono::milliseconds(dispatch_interval_));
-  send_timer_->async_wait(
-      std::bind(&SendGroup::PreDispatchData, this, std::placeholders::_1));
+  send_timer_->async_wait(std::bind(&SendGroup::PreDispatchData, this, std::placeholders::_1));
 
   update_conf_timer_ = std::make_shared<asio::steady_timer>(io_context_);
   update_conf_timer_->expires_after(std::chrono::milliseconds(1));
-  update_conf_timer_->async_wait(
-      std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
+  update_conf_timer_->async_wait(std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
 
   if (SdkConfig::getInstance()->enable_balance_) {
     load_balance_timer_ = std::make_shared<asio::steady_timer>(io_context_);
-    load_balance_timer_->expires_after(
-        std::chrono::milliseconds(load_balance_interval_));
-    load_balance_timer_->async_wait(
-        std::bind(&SendGroup::LoadBalance, this, std::placeholders::_1));
+    load_balance_timer_->expires_after(std::chrono::milliseconds(load_balance_interval_));
+    load_balance_timer_->async_wait(std::bind(&SendGroup::LoadBalance, this, std::placeholders::_1));
   }
 
-  current_bus_vec_.reserve(SdkConfig::getInstance()->max_proxy_num_);
+  current_proxy_vec_.reserve(SdkConfig::getInstance()->max_proxy_num_);
   thread_ = std::thread(&SendGroup::Run, this);
 }
 SendGroup::~SendGroup() {
@@ -84,14 +80,16 @@ SendGroup::~SendGroup() {
     thread_.join();
   }
 }
-void SendGroup::Run() { io_context_.run(); }
+void SendGroup::Run() {
+  prctl(PR_SET_NAME, "send-group");
+  io_context_.run();
+}
 void SendGroup::PreDispatchData(std::error_code error) {
   if (error) {
     return;
   }
   send_timer_->expires_after(std::chrono::milliseconds(dispatch_interval_));
-  send_timer_->async_wait(
-      std::bind(&SendGroup::DispatchData, this, std::placeholders::_1));
+  send_timer_->async_wait(std::bind(&SendGroup::DispatchData, this, std::placeholders::_1));
 }
 
 void SendGroup::DispatchData(std::error_code error) {
@@ -125,8 +123,7 @@ void SendGroup::DispatchData(std::error_code error) {
   }
 
   send_timer_->expires_after(std::chrono::milliseconds(dispatch_interval_));
-  send_timer_->async_wait(
-      std::bind(&SendGroup::DispatchData, this, std::placeholders::_1));
+  send_timer_->async_wait(std::bind(&SendGroup::DispatchData, this, std::placeholders::_1));
 }
 void SendGroup::HeartBeat() {
   unique_read_lock<read_write_mutex> rdlck(work_clients_mutex_);
@@ -148,12 +145,12 @@ void SendGroup::HeartBeat() {
 
 bool SendGroup::IsFull() { return GetQueueSize() > max_send_queue_num_; }
 
-uint32_t SendGroup::PushData(SendBufferPtrT send_buffer_ptr) {
+uint32_t SendGroup::PushData(const SendBufferPtrT &send_buffer_ptr) {
   if (IsFull()) {
     return SdkCode::kSendBufferFull;
   }
   std::lock_guard<std::mutex> lock(mutex_);
-  send_buf_list_.push(send_buffer_ptr);
+  send_proxy_list_.push(send_buffer_ptr);
   return SdkCode::kSuccess;
 }
 
@@ -165,60 +162,53 @@ void SendGroup::UpdateConf(std::error_code error) {
 
   ClearOldTcpClients();
 
-  ProxyInfoVec new_bus_info;
-  if (ProxyManager::GetInstance()->GetProxy(send_group_key_, new_bus_info) !=
-          kSuccess ||
-      new_bus_info.empty()) {
+  ProxyInfoVec new_proxy_info;
+  if (ProxyManager::GetInstance()->GetProxy(send_group_key_, new_proxy_info) != kSuccess || new_proxy_info.empty()) {
     update_conf_timer_->expires_after(std::chrono::milliseconds(kTimerMinute));
-    update_conf_timer_->async_wait(
-        std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
+    update_conf_timer_->async_wait(std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
     return;
   }
-  if (new_bus_info.empty()) {
-    LOG_INFO("UpdateConf new_bus_info is empty!");
+  if (new_proxy_info.empty()) {
+    LOG_INFO("New proxy is empty when update config!");
     return;
   }
 
-  load_threshold_ = new_bus_info[0].GetLoad() > constants::kDefaultLoadThreshold
-                        ? constants::kDefaultLoadThreshold
-                        : std::max((new_bus_info[0].GetLoad()), 0);
+  load_threshold_ = new_proxy_info[0].GetLoad() > constants::kDefaultLoadThreshold
+                    ? constants::kDefaultLoadThreshold
+                    : std::max((new_proxy_info[0].GetLoad()), 0);
 
-  if (!IsConfChanged(current_bus_vec_, new_bus_info)) {
-    LOG_INFO("Don`t need UpdateConf. current bus size("
-             << current_bus_vec_.size() << ")=bus size(" << new_bus_info.size()
-             << ")");
+  if (!IsConfChanged(current_proxy_vec_, new_proxy_info)) {
+    LOG_INFO("Don`t need UpdateConf. current proxy size(" << current_proxy_vec_.size() << ")=proxy size("
+                                                        << new_proxy_info.size() << ")");
     update_conf_timer_->expires_after(std::chrono::milliseconds(kTimerMinute));
-    update_conf_timer_->async_wait(
-        std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
+    update_conf_timer_->async_wait(std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
     return;
   }
 
-  max_proxy_num_ =
-      std::min(SdkConfig::getInstance()->max_proxy_num_, new_bus_info.size());
+  max_proxy_num_ = std::min(SdkConfig::getInstance()->max_proxy_num_, new_proxy_info.size());
 
-  std::shared_ptr<std::vector<TcpClientTPtrT>> tcp_clients_tmp =
-      std::make_shared<std::vector<TcpClientTPtrT>>();
+  std::shared_ptr<std::vector<TcpClientTPtrT>> tcp_clients_tmp = std::make_shared<std::vector<TcpClientTPtrT>>();
   if (tcp_clients_tmp == nullptr) {
-    LOG_INFO("tcp_clients_tmp is  nullptr");
+    LOG_INFO("Tcp clients tmp is nullptr");
     update_conf_timer_->expires_after(std::chrono::milliseconds(kTimerMinute));
-    update_conf_timer_->async_wait(
-        std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
+    update_conf_timer_->async_wait(std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
     return;
   }
 
-  std::random_shuffle(new_bus_info.begin(), new_bus_info.end());
+  std::random_shuffle(new_proxy_info.begin(), new_proxy_info.end());
 
   tcp_clients_tmp->reserve(max_proxy_num_);
   for (int i = 0; i < max_proxy_num_; i++) {
-    ProxyInfo bus_tmp = new_bus_info[i];
-    TcpClientTPtrT tcpClientTPtrT =
-        std::make_shared<TcpClient>(io_context_, bus_tmp.ip(), bus_tmp.port());
-    tcp_clients_tmp->push_back(tcpClientTPtrT);
-    LOG_INFO("new bus info.[" << bus_tmp.ip() << ":" << bus_tmp.port() << "]");
+    ProxyInfo tmp_proxy = new_proxy_info[i];
+    for (int repeat_time = 0; repeat_time < SdkConfig::getInstance()->proxy_repeat_times_; repeat_time++) {
+      TcpClientTPtrT tcpClientTPtrT = std::make_shared<TcpClient>(io_context_, tmp_proxy.ip(), tmp_proxy.port());
+      tcp_clients_tmp->push_back(tcpClientTPtrT);
+      LOG_INFO("New proxy info.[" << tmp_proxy.ip() << ":" << tmp_proxy.port() << "]");
+    }
   }
 
   {
-    LOG_INFO("do change tcp clients.");
+    LOG_INFO("Do change tcp clients.");
     unique_write_lock<read_write_mutex> wtlck(work_clients_mutex_);
     work_clients_old_ = work_clients_;
     work_clients_ = tcp_clients_tmp;
@@ -230,51 +220,43 @@ void SendGroup::UpdateConf(std::error_code error) {
     }
   }
 
-  current_bus_vec_ = new_bus_info;
+  current_proxy_vec_ = new_proxy_info;
 
   InitReserveClient();
 
   update_conf_timer_->expires_after(std::chrono::milliseconds(kTimerMinute));
-  update_conf_timer_->async_wait(
-      std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
+  update_conf_timer_->async_wait(std::bind(&SendGroup::UpdateConf, this, std::placeholders::_1));
 
-  LOG_INFO("Finished UpdateConf.");
+  LOG_INFO("Finished update send group config.");
 }
 
 SendBufferPtrT SendGroup::PopData() {
   std::lock_guard<std::mutex> lock(mutex_);
-  if (send_buf_list_.empty()) {
+  if (send_proxy_list_.empty()) {
     return nullptr;
   }
-  SendBufferPtrT send_buf = send_buf_list_.front();
-  send_buf_list_.pop();
+  SendBufferPtrT send_buf = send_proxy_list_.front();
+  send_proxy_list_.pop();
   return send_buf;
 }
 
 uint32_t SendGroup::GetQueueSize() {
   std::lock_guard<std::mutex> lock(mutex_);
-  return send_buf_list_.size();
+  return send_proxy_list_.size();
 }
 
-bool SendGroup::IsConfChanged(ProxyInfoVec &current_bus_vec,
-                              ProxyInfoVec &new_bus_vec) {
-  if (new_bus_vec.empty())
-    return false;
-  if (current_bus_vec.size() != new_bus_vec.size()) {
+bool SendGroup::IsConfChanged(ProxyInfoVec &current_proxy_vec, ProxyInfoVec &new_proxy_vec) {
+  if (new_proxy_vec.empty()) return false;
+  if (current_proxy_vec.size() != new_proxy_vec.size()) {
     return true;
   }
 
-  for (auto &current_bu : current_bus_vec) {
-    for (int i = 0; i < new_bus_vec.size(); i++) {
-      if ((current_bu.ip() == new_bus_vec[i].ip()) &&
-          (current_bu.port() == new_bus_vec[i].port()))
-        break;
-      if (i == (new_bus_vec.size() - 1)) {
-        if ((current_bu.ip() != new_bus_vec[i].ip() ||
-             current_bu.port() == new_bus_vec[i].port())) {
-          LOG_INFO("current bus ip." << current_bu.ip() << ":"
-                                     << current_bu.port()
-                                     << " can`t find in bus.");
+  for (auto &current_bu : current_proxy_vec) {
+    for (int i = 0; i < new_proxy_vec.size(); i++) {
+      if ((current_bu.ip() == new_proxy_vec[i].ip()) && (current_bu.port() == new_proxy_vec[i].port())) break;
+      if (i == (new_proxy_vec.size() - 1)) {
+        if ((current_bu.ip() != new_proxy_vec[i].ip() || current_bu.port() == new_proxy_vec[i].port())) {
+          LOG_INFO("current proxy ip." << current_bu.ip() << ":" << current_bu.port() << " can`t find in proxy.");
           return true;
         }
       }
@@ -312,8 +294,7 @@ void SendGroup::LoadBalance(std::error_code error) {
   uint64_t interval = load_balance_interval_ + rand() % 120 * 1000;
   LOG_INFO("LoadBalance interval:" << interval);
   load_balance_timer_->expires_after(std::chrono::milliseconds(interval));
-  load_balance_timer_->async_wait(
-      std::bind(&SendGroup::LoadBalance, this, std::placeholders::_1));
+  load_balance_timer_->async_wait(std::bind(&SendGroup::LoadBalance, this, std::placeholders::_1));
 }
 
 void SendGroup::DoLoadBalance() {
@@ -328,17 +309,13 @@ void SendGroup::DoLoadBalance() {
     return;
   }
 
-  if ((work_client->GetAvgLoad() - reserve_client->GetAvgLoad()) >
-      load_threshold_) {
-    LOG_INFO("DoLoadBalance " << reserve_client->getClientInfo() << "replace"
-                              << work_client->getClientInfo() << ",load[work "
-                              << work_client->GetAvgLoad() << "][reserve "
-                              << reserve_client->GetAvgLoad() << "][threshold "
-                              << load_threshold_ << "]");
+  if ((work_client->GetAvgLoad() - reserve_client->GetAvgLoad()) > load_threshold_) {
+    LOG_INFO("DoLoadBalance " << reserve_client->getClientInfo() << "replace" << work_client->getClientInfo()
+                              << ",load[work " << work_client->GetAvgLoad() << "][reserve "
+                              << reserve_client->GetAvgLoad() << "][threshold " << load_threshold_ << "]");
     std::string ip = work_client->getIp();
     uint32_t port = work_client->getPort();
-    work_client->UpdateClient(reserve_client->getIp(),
-                              reserve_client->getPort());
+    work_client->UpdateClient(reserve_client->getIp(), reserve_client->getPort());
 
     ProxyInfo proxy = GetRandomProxy(ip, port);
     if (!proxy.ip().empty()) {
@@ -350,12 +327,10 @@ void SendGroup::DoLoadBalance() {
 }
 bool SendGroup::NeedDoLoadBalance() {
   unique_read_lock<read_write_mutex> rdlck(work_clients_mutex_);
-  if (load_threshold_ <= 0 ||
-      work_clients_->size() == current_bus_vec_.size()) {
-    LOG_INFO("Don`t need DoLoadBalance [load_threshold]:"
-             << load_threshold_
-             << ",[tcp_client size]:" << work_clients_->size()
-             << ",[current_bus_vec size]:" << current_bus_vec_.size());
+  if (load_threshold_ <= 0 || work_clients_->size() == current_proxy_vec_.size()) {
+    LOG_INFO("Don`t need DoLoadBalance [load_threshold]:" << load_threshold_
+                                                          << ",[tcp_client size]:" << work_clients_->size()
+                                                          << ",[current_proxy_vec size]:" << current_proxy_vec_.size());
     need_balance_ = false;
     return false;
   }
@@ -363,12 +338,11 @@ bool SendGroup::NeedDoLoadBalance() {
   return true;
 }
 void SendGroup::InitReserveClient() {
-  if (max_proxy_num_ >= current_bus_vec_.size()) {
+  if (max_proxy_num_ >= current_proxy_vec_.size()) {
     return;
   }
-  uint64_t max_reserve_num = current_bus_vec_.size() - max_proxy_num_;
-  uint64_t reserve_num =
-      std::min(SdkConfig::getInstance()->reserve_proxy_num_, max_reserve_num);
+  uint64_t max_reserve_num = current_proxy_vec_.size() - max_proxy_num_;
+  uint64_t reserve_num = std::min(SdkConfig::getInstance()->reserve_proxy_num_, max_reserve_num);
   if (reserve_num <= 0) {
     return;
   }
@@ -376,15 +350,12 @@ void SendGroup::InitReserveClient() {
   unique_write_lock<read_write_mutex> wtlck(reserve_clients_mutex_);
   reserve_clients_.clear();
 
-  for (uint64_t i = current_bus_vec_.size() - reserve_num;
-       i < current_bus_vec_.size(); i++) {
-    ProxyInfo bus_tmp = current_bus_vec_[i];
-    TcpClientTPtrT tcpClientTPtrT =
-        std::make_shared<TcpClient>(io_context_, bus_tmp.ip(), bus_tmp.port());
+  for (uint64_t i = current_proxy_vec_.size() - reserve_num; i < current_proxy_vec_.size(); i++) {
+    ProxyInfo tmp_proxy = current_proxy_vec_[i];
+    TcpClientTPtrT tcpClientTPtrT = std::make_shared<TcpClient>(io_context_, tmp_proxy.ip(), tmp_proxy.port());
     reserve_clients_.push_back(tcpClientTPtrT);
   }
-  LOG_INFO(
-      "InitReserveClient reserve_clients size:" << reserve_clients_.size());
+  LOG_INFO("InitReserveClient reserve_clients size:" << reserve_clients_.size());
 }
 bool SendGroup::UpSort(const TcpClientTPtrT &begin, const TcpClientTPtrT &end) {
   if (begin && end) {
@@ -409,14 +380,13 @@ TcpClientTPtrT SendGroup::GetMaxLoadClient() {
 
 ProxyInfo SendGroup::GetRandomProxy(const std::string &ip, uint32_t port) {
   ProxyInfo proxy_info;
-  for (auto &it : current_bus_vec_) {
+  for (auto &it : current_proxy_vec_) {
     if (it.ip() == ip && it.port() == port) {
       continue;
     }
     bool exist = false;
     for (int index = 0; index < reserve_clients_.size(); index++) {
-      if (it.ip() == reserve_clients_[index]->getIp() &&
-          it.port() == reserve_clients_[index]->getPort()) {
+      if (it.ip() == reserve_clients_[index]->getIp() && it.port() == reserve_clients_[index]->getPort()) {
         exist = true;
         break;
       }
@@ -444,8 +414,7 @@ TcpClientTPtrT SendGroup::GetReserveClient() {
     }
     bool exist = false;
     for (int index = 0; index < work_clients_->size(); index++) {
-      if (it->getIp() == (*work_clients_)[index]->getIp() &&
-          it->getPort() == (*work_clients_)[index]->getPort()) {
+      if (it->getIp() == (*work_clients_)[index]->getIp() && it->getPort() == (*work_clients_)[index]->getPort()) {
         exist = true;
         break;
       }
@@ -461,11 +430,10 @@ TcpClientTPtrT SendGroup::GetReserveClient() {
 bool SendGroup::ExistInWorkClient(const std::string &ip, uint32_t port) {
   unique_read_lock<read_write_mutex> rdlck(work_clients_mutex_);
   for (int index = 0; index < work_clients_->size(); index++) {
-    if (ip == (*work_clients_)[index]->getIp() &&
-        port == (*work_clients_)[index]->getPort()) {
+    if (ip == (*work_clients_)[index]->getIp() && port == (*work_clients_)[index]->getPort()) {
       return true;
     }
   }
   return false;
 }
-} // namespace inlong
+}  // namespace inlong
