@@ -18,8 +18,8 @@
 package org.apache.inlong.sdk.dataproxy.common;
 
 public enum SendResult {
-    INVALID_ATTRIBUTES, // including DataProxyErrCode(100,101,102,112)
     OK,
+    INVALID_ATTRIBUTES, // including DataProxyErrCode(100,101,102,112)
     TIMEOUT,
     CONNECTION_BREAK,
     THREAD_INTERRUPT,
@@ -31,6 +31,13 @@ public enum SendResult {
     UNCONFIGURED_GROUPID_OR_STREAMID, // DataProxyErrCode(113)
     TOPIC_IS_BLANK, // DataProxyErrCode(115)
     DATAPROXY_FAIL_TO_RECEIVE, // DataProxyErrCode(114,116,117,118,119,120)
+    MESSAGE_TOO_LARGE,
+    WRITE_OVER_WATERMARK, /* error when water overflow */
+    MAX_FLIGHT_ON_ALL_CONNECTION,
+    NO_REMOTE_NODE_META_INFOS,
+    EMPTY_ACTIVE_NODE_SET,
+    NO_VALID_REMOTE_NODE,
+    SENDER_CLOSED,
 
     UNKOWN_ERROR
 }
