@@ -18,9 +18,10 @@
 package org.apache.inlong.sdk.dataproxy.utils;
 
 import org.apache.inlong.common.msg.AttributeConstants;
+import org.apache.inlong.sdk.dataproxy.ConfigConstants;
 import org.apache.inlong.sdk.dataproxy.ProxyClientConfig;
-import org.apache.inlong.sdk.dataproxy.network.Utils;
 
+import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -92,6 +93,50 @@ public class ProxyUtils {
         return true;
     }
 
+    /**
+     * Check if the body length exceeds the maximum limit, if the maximum limit is less than 0, it is not checked
+     * @param body
+     * @param maxLen
+     * @return
+     */
+    public static boolean isBodyLengthValid(byte[] body, int maxLen) {
+        // Not valid if the maximum limit is less than or equal to 0
+        if (maxLen < 0) {
+            return true;
+        }
+        // Reserve space for attribute
+        if (body.length > maxLen - ConfigConstants.RESERVED_ATTRIBUTE_LENGTH) {
+            logger.debug("body length({}) > max length({}) - fixed attribute length({})",
+                    body.length, maxLen, ConfigConstants.RESERVED_ATTRIBUTE_LENGTH);
+            return false;
+        }
+        return true;
+    }
+
+    /**
+     * Check if the total body length exceeds the maximum limit, if the maximum limit is less than 0, it is not checked
+     * @param bodyList
+     * @param maxLen
+     * @return
+     */
+    public static boolean isBodyLengthValid(List<byte[]> bodyList, int maxLen) {
+        // Not valid if the maximum limit is less than or equal to 0
+        if (maxLen < 0) {
+            return true;
+        }
+        int size = 0;
+        for (byte[] body : bodyList) {
+            size += body.length;
+        }
+        // Reserve space for attribute
+        if (size > maxLen - ConfigConstants.RESERVED_ATTRIBUTE_LENGTH) {
+            logger.debug("bodyList length({}) > max length({}) - fixed attribute length({})",
+                    size, maxLen, ConfigConstants.RESERVED_ATTRIBUTE_LENGTH);
+            return false;
+        }
+        return true;
+    }
+
     public static long covertZeroDt(long dt) {
         if (dt == 0) {
             return System.currentTimeMillis();
@@ -105,11 +150,11 @@ public class ProxyUtils {
      * @param clientConfig
      */
     public static void validClientConfig(ProxyClientConfig clientConfig) {
-        if (clientConfig.isNeedAuthentication()) {
-            if (Utils.isBlank(clientConfig.getUserName())) {
-                throw new IllegalArgumentException("Authentication require userName not Blank!");
+        if (clientConfig.isEnableAuthentication()) {
+            if (StringUtils.isBlank(clientConfig.getAuthSecretId())) {
+                throw new IllegalArgumentException("Authentication require secretId not Blank!");
             }
-            if (Utils.isBlank(clientConfig.getSecretKey())) {
+            if (StringUtils.isBlank(clientConfig.getAuthSecretKey())) {
                 throw new IllegalArgumentException("Authentication require secretKey not Blank!");
             }
         }
