@@ -67,10 +67,17 @@ public class IcebergSourceReader<T>
     }
     @Override
     public List<IcebergSourceSplit> snapshotState(long checkpointId) {
-        metrics.flushAudit();
+        metrics.updateCurrentCheckpointId(checkpointId);
         return super.snapshotState(checkpointId);
     }
 
+    @Override
+    public void notifyCheckpointComplete(long checkpointId) throws Exception {
+        super.notifyCheckpointComplete(checkpointId);
+        metrics.flushAudit();
+        metrics.updateLastCheckpointId(checkpointId);
+    }
+
     @Override
     protected IcebergSourceSplit initializedState(IcebergSourceSplit split) {
         return split;
